@@ -112,6 +112,7 @@ enum evdev_device_model {
 	EVDEV_MODEL_JUMPING_SEMI_MT = (1 << 10),
 	EVDEV_MODEL_LOGITECH_K400 = (1 << 11),
 	EVDEV_MODEL_LENOVO_X220_TOUCHPAD_FW81 = (1 << 12),
+	EVDEV_MODEL_LENOVO_CARBON_X1_6TH = (1 << 13),
 	EVDEV_MODEL_CYBORG_RAT = (1 << 14),
 	EVDEV_MODEL_HP_STREAM11_TOUCHPAD = (1 << 16),
 	EVDEV_MODEL_LENOVO_T450_TOUCHPAD= (1 << 17),
@@ -126,6 +127,7 @@ enum evdev_device_model {
 	EVDEV_MODEL_LOGITECH_MARBLE_MOUSE = (1 << 26),
 	EVDEV_MODEL_TABLET_NO_PROXIMITY_OUT = (1 << 27),
 	EVDEV_MODEL_MS_NANO_TRANSCEIVER = (1 << 28),
+	EVDEV_MODEL_TABLET_MODE_NO_SUSPEND = (1 << 30),
 };
 
 enum evdev_button_scroll_state {
